/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.stp.core.delete.operations;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.stp.core.infrastructure.assertion.Assert;
import org.eclipse.stp.core.infrastructure.emf.EditModelException;
import org.eclipse.stp.core.infrastructure.emf.IEditModelScribbler;
import org.eclipse.stp.core.infrastructure.operations.AbstractScribblerOperation;
import org.eclipse.stp.core.sca.SCAObject;
import org.eclipse.wst.common.frameworks.datamodel.IDataModel;

public class DeleteRootSCAModelOperation extends AbstractScribblerOperation {
   public DeleteRootSCAModelOperation() {
      super();
   }

   public DeleteRootSCAModelOperation(IDataModel model) {
      super(model);
   }

   public IStatus doExecute(IProgressMonitor monitor) throws ExecutionException {
      SCAObject eObjectToDelete = (SCAObject) model
            .getProperty(IDeleteRootSCAModelDataModelProperties.SCAOBJECT_TO_DELETE);

      IEditModelScribbler scribbler = getEditModelScribbler();
      Assert.isNotNull(scribbler);

      Resource resource = eObjectToDelete.getEObject().eResource();
      if (resource != null) {
         try {
            scribbler.deleteResource(resource, monitor);
         } catch (EditModelException e) {
            e.printStackTrace();
         }
      }

      return OK_STATUS;
   }

   protected IStatus doRedo(IProgressMonitor monitor) throws ExecutionException {
      // TODO Auto-generated method stub
      return null;
   }

   protected IStatus doUndo(IProgressMonitor monitor) throws ExecutionException {
      // TODO Auto-generated method stub
      return null;
   }
}
